@@ -89,18 +89,20 @@ def setup_parser():
         dest="watch", action="store_true", default=False)
     parser.add_argument(
         '-r', "--retry", default=0, type=int, dest="retry_count",
-        help=("Resolve unit errors via retry."
+        help=("Resolve CLI and unit errors via number of retries (default: 0)."
               " Either standalone or in a deployment"))
     parser.add_argument(
         "--diff", action="store_true", default=False,
-        help=("Resolve unit errors via retry."
-              " Either standalone or in a deployment"))
+        help=("Generate a delta between a configured deployment and a running"
+             " environment."))
     parser.add_argument(
         '-w', '--relation-wait', action='store', dest='rel_wait',
         default=60, type=int,
         help=('Number of seconds to wait before checking for '
               'relation errors after all relations have been added '
               'and subordinates started. (default: 60)'))
+    parser.add_argument("--description", help=argparse.SUPPRESS,
+                        action="store_true")
     parser.add_argument("deployment", nargs="?")
     return parser
 
@@ -119,6 +121,10 @@ def run():
     parser = setup_parser()
     options = parser.parse_args()
 
+    if options.description:
+        print "Tool for declarative management of complex deployments."
+        sys.exit(0)
+
     # Debug implies watching and verbose
     if options.debug:
         options.watch = options.verbose = True
@@ -127,7 +133,7 @@ def run():
     log = logging.getLogger("deployer.cli")
     start_time = time.time()
 
-    env = select_runtime(options.juju_env)
+    env = select_runtime(options.juju_env, options)
     log.debug('Using runtime %s', env.__class__.__name__)
 
     config = ConfigStack(options.configs or [])
@@ -153,6 +159,7 @@ def run():
                         options.find_service)
         else:
             log.info("Service: %s address: %s", options.find_service, address)
+            print address
         sys.exit(0)
 
     # Just resolve/retry hooks in the environment
