@@ -15,6 +15,11 @@ class BaseEnvironment(object):
         env_config_path = path_join(jhome, 'environments.yaml')
         return env_config_path
 
+    def _check_call(self, *args, **kwargs):
+        if self.options and self.options.retry_count:
+            kwargs['max_retry'] = self.options.retry_count
+        return _check_call(*args, **kwargs)
+
     def _named_env(self, params):
         if self.name:
             params.extend(["-e", self.name])
@@ -80,7 +85,8 @@ class BaseEnvironment(object):
                 params.extend["--force-machine=%d" % force_machine]
 
             params.extend([charm_url, name])
-            _check_call(params, self.log, "Error deploying service %r", name)
+            self._check_call(
+                params, self.log, "Error deploying service %r", name)
 
     def terminate_machine(self, mid, wait=False):
         """Terminate a machine.
@@ -95,7 +101,8 @@ class BaseEnvironment(object):
         params = self._named_env(["juju", "terminate-machine"])
         params.append(mid)
         try:
-            _check_call(params, self.log, "Error terminating machine %r" % mid)
+            self._check_call(
+                params, self.log, "Error terminating machine %r" % mid)
         except ErrorExit, e:
             if ("machine %s does not exist" % mid) in e.error.output:
                 return
@@ -115,7 +122,7 @@ class BaseEnvironment(object):
     def get_cli_status(self):
         params = self._named_env(["juju", "status"])
         with open('/dev/null', 'w') as fh:
-            output = _check_call(
+            output = self._check_call(
                 params, self.log, "Error getting status, is it bootstrapped?",
                 stderr=fh)
         status = yaml_load(output)
